==> kubernetes-model-0.1.2-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentCauseImageTriggerFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class DeploymentCauseImageTriggerFluent<T extends DeploymentCauseImageTriggerFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     VisitableBuilder<ObjectReference, ?> from;     Map<String, Object> additionalProperties = new HashMap();

    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNested<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNested<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class FromNested<N> extends ObjectReferenceFluent<FromNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N and(){
            return (N) DeploymentCauseImageTriggerFluent.this.withFrom(builder.build());
        }
            public N endFrom(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.10-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentCauseImageTriggerFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class DeploymentCauseImageTriggerFluent<T extends DeploymentCauseImageTriggerFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     VisitableBuilder<ObjectReference, ?> from;     Map<String, Object> additionalProperties = new HashMap();

    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNested<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNested<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentCauseImageTriggerFluent that = (DeploymentCauseImageTriggerFluent) o;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNested<N> extends ObjectReferenceFluent<FromNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             FromNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) DeploymentCauseImageTriggerFluent.this.withFrom(builder.build());
        }
    
}


}
